.component-container{overflow:auto;width:calc(100% - 10px)}.chips-container{padding-left:0;white-space:nowrap;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}div.the-chip{background-color:#fff;border:.5px solid;color:#000;margin-left:5px}span.chip-value{align-items:flex-end;border:1px solid;border-radius:50%;color:#000;display:flex;font-size:10px;font-weight:700;justify-content:center}::-webkit-scrollbar{height:7px;margin-top:10px}::-webkit-scrollbar-thumb{background-color:#000;border-radius:999px;height:5px}
/*# sourceMappingURL=main.bf5efdfa.css.map*/